- To get the most out of AlphaHuman, you need to connect at least one account to your assistant. The more
+ To get the most out of AlphaHuman, you need to connect at least one account. The more
accounts you connect, the more powerful the intelligence will be.
AlphaHuman saves all data and credentials
- locally and follows a strict zero-data retention policy when it communicats with different AI mod
+ locally and follows a strict zero-data retention policy so you won't have to worry about anything
+ getting leaked.
diff --git a/src/pages/onboarding/steps/FeaturesStep.tsx b/src/pages/onboarding/steps/FeaturesStep.tsx
index 15d5ea607..7cc58ba91 100644
--- a/src/pages/onboarding/steps/FeaturesStep.tsx
+++ b/src/pages/onboarding/steps/FeaturesStep.tsx
@@ -7,16 +7,16 @@ interface FeaturesStepProps {
const FeaturesStep = ({ onNext }: FeaturesStepProps) => {
const features = [
{
- title: 'Keeps you on track',
- description: 'Organize your chats and tasks, finds you alpha and gets you deep insights. Get more done!',
+ title: 'Keep track of Everything',
+ description: 'Sometimes your chats, emails, tasks can get a bit too much. Stay on track, organize things and get more done.',
},
{
title: 'Has Infinite Memory & Learns',
- description: 'Your assistant can remember everything you tell it and learn from your interactions to help you get more done.',
+ description: 'Missed something? Have a sexy assistant give you exactly what you need, every time.',
},
{
title: 'Trades the Trenches',
- description: 'Your assistant comes with it\'s own private wallet that can trade on any exchange for you.',
+ description: 'With it\'s own private wallet, trade or reasearch on any exchange or shitcoin autonomously. Go big or go home.',
},
];
@@ -25,7 +25,7 @@ const FeaturesStep = ({ onNext }: FeaturesStepProps) => {
Are You Ready For This?
- Here are a few things that AlphaHuman can do that might surprise you.
+ Here's some of the things that AlphaHuman can do
- Alright you're all set up, just message the bot you're ready to cook!
+ Alright you're all set up, just message your assistant and you're ready to cook!
- Send a message to the bot to get started. Try asking about crypto prices, market trends, or anything crypto-related!
+ Send a message to the bot to get started. Try asking about crypto prices, market trends, or anything about your chats!
- Your assistant will automatically start connecting to your accounts and tools to help you get more done.
+ Your assistant will automatically start connecting to your accounts and tools to get insights and help you get more done.
@@ -74,10 +74,7 @@ const GetStartedStep = ({ onComplete }: GetStartedStepProps) => {
onClick={handleOpenTelegram}
className="w-full flex items-center justify-center space-x-3 bg-blue-500 hover:bg-blue-600 active:bg-blue-700 text-white font-semibold py-2.5 text-sm rounded-xl transition-all duration-300 hover:shadow-medium mb-3"
>
-
- Let's Cook! 🔥
+ I'm Ready to Cook! 🔥
);
diff --git a/src/pages/onboarding/steps/PrivacyStep.tsx b/src/pages/onboarding/steps/PrivacyStep.tsx
index d2e9393e6..a9bf0ee22 100644
--- a/src/pages/onboarding/steps/PrivacyStep.tsx
+++ b/src/pages/onboarding/steps/PrivacyStep.tsx
@@ -43,7 +43,7 @@ const PrivacyStep = ({ onNext }: PrivacyStepProps) => {
onClick={onNext}
className="btn-primary w-full py-2.5 text-sm font-medium rounded-xl"
>
- Love the Privacy first features! Continue!
+ Got it! Let's Continue 👀
);
diff --git a/tailwind.config.js b/tailwind.config.js
index 577265760..23af20fe7 100644
--- a/tailwind.config.js
+++ b/tailwind.config.js
@@ -25,19 +25,19 @@ module.exports = {
300: '#D4D4D1', // Hover states
},
// Primary - Premium ocean blue with depth
primary: {
50: '#F0F7FF',
100: '#E0EFFF',
200: '#C7E2FF',
300: '#A5D0FF',
400: '#7AB5FF',
- 500: '#5B9BF3', // Main brand - sophisticated blue
- 600: '#4A83DD', // Hover state
- 700: '#3D6DC4', // Active state
- 800: '#345A9F',
- 900: '#2D4B7F',
- 950: '#1E3052',
+ 500: '#4A83DD', // Main brand - darker blue for dark backgrounds
+ 600: '#3D6DC4', // Hover state
+ 700: '#345A9F', // Active state
+ 800: '#2D4B7F',
+ 900: '#1E3052',
+ 950: '#0F1A2E',
},
// Sage - Success and growth (sophisticated green)
@@ -25,19 +25,19 @@ module.exports = {
300: '#D4D4D1', // Hover states
},
- // Primary - Premium ocean blue with depth
+ // Primary - Premium ocean blue with depth (optimized for dark backgrounds)
primary: {
50: '#F0F7FF',